require 'fileutils'
require 'git'
require 'os'

module SwissKnife
  def install_homebrew
    system 'ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"'
  end

  def install_rvm
    system 'curl -sSL https://get.rvm.io | bash -s stable --ruby'
  end

  class Util
    def exit
      Process.kill 'HUP', Process.ppid
    end

    def clear_screen
      puts '%c[2J' % 27
    end

    def pack
      if system 'bundle --path vendor/bundle'
        puts "\nDependencies prepared successfully!"
      else
        puts "\nSomething went wrong..."
      end
    end

    def git_add(file)
      git = Git.open Dir.pwd

      if file == nil
        git.add all: true
      else
        git.add file
      end
    end

    def git_branch(branch)
      git = Git.open Dir.pwd
      git.branch branch
    end

    def git_clone_or_commit(message)
      git = Git.open Dir.pwd

      if message.include? '.git'
        name = message.split('/')[4]
        name.slice! '.git'
        Git.clone message, name
        puts "Successfully cloned the \"#{name}\" project!"
      else
        git.commit message
        puts "Created commit: \"#{message}\""
      end
    end

    def git_push(remote, branch)
      git = Git.open Dir.pwd
      git.push remote, branch
      puts "Push to #{branch} was successful!"
    end

    def install(program)
      case program
        when 'homebrew' || 'brew'
          install_homebrew
        when 'rvm'
          if system 'brew doctor'
            install_rvm
          else
            install_homebrew
            install_rvm
          end
        else
          puts "I don't know what #{program} is!"
      end
    end

    def delete(file)
      FileUtils.rm_r file, secure: true
    end

    def clean
      junk = %w(.DS_Store _MACOSX Thumbs.db)
      junk.each { |litter| delete litter }
    end

    def move(file, destination)
      FileUtils.mv file, destination
    end

    def copy(file, destination)
      FileUtils.copy_entry file, destination, preserve: true, remove_destination: true
    end
  end
end